<?php
/*
Plugin Name: Flourish WooCommerce Lock
Plugin URI: https://www.flourishsoftware.com/
Description: This plugin restricts access to WooCommerce pages for users who are not logged in and redirects them to the login page. It also modifies Elementor widget content for non-logged users.
Version: 1.0
Author: Flourish Software
Author URI: https://www.flourishsoftware.com/
License: GPL2
*/
 
add_action( 'template_redirect', 'pd_lock_woocommerce' );
function pd_lock_woocommerce() {
    if ( !is_user_logged_in() && !is_account_page() ) {
        if ( is_woocommerce() || is_cart() || is_checkout() || is_product() || is_product_category() || is_shop() || is_search() || is_product_tag() ) {
            wp_redirect( get_permalink( get_option('woocommerce_myaccount_page_id') ) );
            exit;
        }
    }
}

add_filter( 'elementor/widget/render_content', 'pd_lock_woocommerce_elementor_widgets', 10, 2 ); 
function pd_lock_woocommerce_elementor_widgets( $widget_content, $widget ) {
    if ( !is_user_logged_in() ) {
        $categories = $widget->get_categories();
        if ( in_array( 'woocommerce-elements', $categories ) ) {
            if ( $widget->get_name() == 'woocommerce-menu-cart' ) {
                return '';
            }
            return '<p>Please Log In</p>';
        }
    }
    return $widget_content;
}

add_filter( 'render_block', 'pd_lock_woocommerce_blocks', 10, 2 );
function pd_lock_woocommerce_blocks( $block_content, $block ) {
    if ( !is_user_logged_in() ) {
        if ( strpos( $block['blockName'], 'woocommerce/' ) === 0 ) {
            return '<center><p>Please Log In</p></center>';
        }
    }
    return $block_content;
}
